Changes
=======

v0.1.0 (2013-05-05)
-------------------

* Initial release

v0.1.1 (2013-05-05)
-------------------

* Adds zhon.cedict package to setup.py

v0.2.0 (2013-05-07)
-------------------

* Allows for mapping between simplified and traditional.
* Adds logging to build_string().
* Adds constants for numbered Pinyin and accented Pinyin.

v0.2.1 (2013-05-07)
-------------------

* Fixes typo in README.rst.

v.1.0.0 (2014-01-25)
--------------------

* Complete rewrite that refactors code, renames constants, and improves Pinyin
  support.
